==> gkl_0.8.9+dfsg.orig.tar.xz: GKL-0.8.9/src/main/java/com/intel/gkl/compression/IntelInflaterFactory.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2016-2021 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.intel.gkl.compression;

import htsjdk.samtools.util.zip.InflaterFactory;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import java.io.File;
import java.util.zip.Inflater;

/**
 * Created by pnvaidya on 2/1/17.
 */
public class IntelInflaterFactory extends InflaterFactory {
    private final static Logger logger = LogManager.getLogger(IntelInflaterFactory.class);
    private boolean intelInflaterSupported;

    public IntelInflaterFactory(File tmpDir) {
        intelInflaterSupported = new IntelInflater().load(tmpDir);
    }

    public IntelInflaterFactory() {
        this(null);
    }

    public Inflater makeInflater(final boolean nowrap) {
        if (intelInflaterSupported && nowrap) {
            return new IntelInflater(nowrap);
        }
        logger.warn("IntelInflater is not supported, using Java.util.zip.Inflater");
        return new Inflater(nowrap);
    }

    public boolean usingIntelInflater() {
        return intelInflaterSupported;
    }
}

==> gkl_0.8.10+dfsg.orig.tar.xz: GKL-0.8.10/src/main/java/com/intel/gkl/compression/IntelInflaterFactory.java <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2016-2021 Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.intel.gkl.compression;

import htsjdk.samtools.util.zip.InflaterFactory;

import org.apache.commons.logging.LogFactory;
import org.apache.commons.logging.Log;

import java.io.File;
import java.util.zip.Inflater;

/**
 * Created by pnvaidya on 2/1/17.
 */
public class IntelInflaterFactory extends InflaterFactory {
    private final static Log logger = LogFactory.getLog(IntelInflaterFactory.class);
    private boolean intelInflaterSupported;

    public IntelInflaterFactory(File tmpDir) {
        intelInflaterSupported = new IntelInflater().load(tmpDir);
    }

    public IntelInflaterFactory() {
        this(null);
    }

    public Inflater makeInflater(final boolean nowrap) {
        if (intelInflaterSupported && nowrap) {
            return new IntelInflater(nowrap);
        }
        logger.warn("IntelInflater is not supported, using Java.util.zip.Inflater");
        return new Inflater(nowrap);
    }

    public boolean usingIntelInflater() {
        return intelInflaterSupported;
    }
}
